@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::GETTY;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: BeLike::GETTY when you build your dists
-$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.113';
+$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.114';
 use Moose;
 use Moose::Autobox;
 use Dist::Zilla;
@@ -55,6 +55,13 @@ has release_branch => (
   default => sub { $_[0]->payload->{release_branch} || 'master' },
 );
 
+has deprecated => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{deprecated} },
+);
+
 has no_github => (
   is      => 'ro',
   isa     => 'Bool',
@@ -269,6 +276,12 @@ sub configure {
     ));
   }
 
+  if ($self->deprecated) {
+    $self->add_plugins(qw(
+      Deprecated
+    ));
+  }
+
   unless ($self->manual_version) {
     if ($self->is_task) {
       my $v_format = q<{{cldr('yyyyMMdd')}}>
@@ -421,7 +434,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.113
+version 0.114
 
 =head1 SYNOPSIS
 
@@ -441,6 +454,7 @@ are default):
 
   [@Author::GETTY]
   author = GETTY
+  deprecated = 0
   release_branch = master
   weaver_config = @Author::GETTY
   no_cpan = 0
@@ -556,6 +570,10 @@ only required parameter here is C<alien_repo>:
 This is used to name the L<CPAN|http://www.cpan.org/> author of the
 distribution. See L<Dist::Zilla::Plugin::Authority/authority>.
 
+=head2 deprecated
+
+Adds L<Dist::Zilla::Plugin::Deprecated> to the distribution.
+
 =head2 release_branch
 
 This variable is used to set the release_branch, only releases on this branch
